AppleAppAttestProvider class

App Attest provider for Apple platforms (Firebase recommended).

Only available on iOS 14.0+, macOS 14.0+.

See documentation: https://firebase.google.com/docs/app-check/ios/app-attest-provider

Inheritance

Constructors

AppleAppAttestProvider()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited