WebDebugProvider class
Debug provider for Web.
Sets self.FIREBASE_APPCHECK_DEBUG_TOKEN before initializing App Check.
If debugToken is provided, that token is used. Otherwise the Firebase JS
SDK auto-generates one and prints it to the browser console — you then
register that token in the Firebase Console.
See documentation: https://firebase.google.com/docs/app-check/web/debug-provider
Constructors
- WebDebugProvider({String? debugToken})
- Creates a web debug provider with an optional debug token.
Properties
- debugToken → String?
-
The debug token for this provider.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- siteKey → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited